import java.io.*;

 /** Esta  uma implementao da interface CatalogoTelefonico que
  *   usa um vetor para armazenar os dados.
  *   @author Koffman & Wolfgang
  */

public class CTBaseadoVetor
    implements CatalogoTelefonico {

  // Campos de Dados

  /** A capacidade inicial do vetor */
  private static final int CAPACIDADE_INICIAL = 100;

  /** A capacidade atual do vetor */
  private int capacidade = CAPACIDADE_INICIAL;

  /** O tamanho atual do vetor (quantidade de entradas do catlogo) */
  private int tamanho = 0;

  /** O vetor que armazenar os dados do catlogo */
  private EntradaCatalogo[] oCatalogo =
      new EntradaCatalogo[capacidade];

  /** O arquivo de dados que conter os dados do catlogo */
  private String nomeDaFonte = null;

  /** Flag booleano para indicar se o catlogo foi alterado desde que
      foi carregado ou salvo. */
  private boolean modificado = false;

  /** Mtodo para carregar o arquivo de dados.
       pr: O espao de armazenamento do catlogo foi criado e est vazio. 
        Se o arquivo existir, deve ser composto por pares nome-nmero 
        em linhas adjacentes.
       ps: Os dados do arquivo so carregados no catlogo.
       @param nomeDaFonte O nome do arquivo de dados
   */
  public void carregaDados(String nomeDaFonte) {
    // Enfatiza o nome do catlogo.
    this.nomeDaFonte = nomeDaFonte;
    try {
      // Cria um BufferedReader para o arquivo.
      BufferedReader entrada = new BufferedReader(
          new FileReader(nomeDaFonte));
      String nome;
      String numero;

      // L cada nome e nmero e adiciona a entrada ao vetor.
      while ( (nome = entrada.readLine()) != null) {
        // L o nome e nmero nas linhas sucessivas.
        if ( (numero = entrada.readLine()) == null) {
          break; // Nenhum nmero lido, sai do lao.
        }
        // Adiciona uma entrada para esse nome e nmero.
        adiciona(nome, numero);
      }

      // Fecha o arquivo.
      entrada.close();
    }
    catch (FileNotFoundException ex) {
      // No faz nada - nenhum dado a carregar.
      return;
    }
    catch (IOException ex) {
      System.err.println("Falha ao carregar catlogo.");
      ex.printStackTrace();
      System.exit(1);
    }
  }

  /** Adiciona uma entrada ou altera uma entrada existente.
      @param nome O nome da pessoa que est sendo adicionado ou alterado
      @param numero O novo nmero a ser atribudo
      @return O nmero anterior ou, se for uma entrada nova, null.
   */
  public String adicionaOuAlteraEntrada(String nome, String numero) {
    String numeroAnt = null;
    int indice = procura(nome);
    if (indice > -1) {
      numeroAnt = oCatalogo[indice].obtemNumero();
      oCatalogo[indice].fixaNumero(numero);
    }
    else {
      adiciona(nome, numero);
    }
    modificado = true;
    return numeroAnt;
  }

  /** Procura uma entrada.
      @param nome O nome da pessoa
      @return O nmero. Se no existir no catlogo, null ser retornado
   */
  public String procuraEntrada(String nome) {
    int indice = procura(nome);
    if (indice > -1) {
      return oCatalogo[indice].obtemNumero();
    }
    else {
      return null;
    }
  }

  /** Mtodo para gravao do catlogo.
      pr: O catlogo foi carregado com dados.
      ps: O contedo do catlogo  gravado novamente no arquivo na 
            forma de pares nome-nmero em linhas adjacentes.
            modificado  redefinida com false.
   */
  public void salva() {
    if (modificado) { // Se no foi alterado, no faz nada.
      try {
        // Cria um PrintWriter para o arquivo.
        PrintWriter saida = new PrintWriter(
            new FileWriter(nomeDaFonte));

        // Grava cada entrada do catlogo no arquivo.
        for (int i = 0; i < tamanho; i++) {
          // Grava o nome.
          saida.println(oCatalogo[i].obtemNome());
          // Grava o nmero.
          saida.println(oCatalogo[i].obtemNumero());
        }

        // Fecha o arquivo e redefine modificado.
        saida.close();
        modificado = false;
      }
      catch (Exception ex) {
        System.err.println("Falha ao salvar catlogo");
        ex.printStackTrace();
        System.exit(1);
      }
    }
  }

  /** Procura uma entrada no catlogo.
      @param nome O nome a ser encontrado
      @return O ndice da entrada que tem o nome solicitado.
              Se o nome no existir no catlogo, retornar -1
   */
  private int procura(String nome) {
    for (int i = 0; i < tamanho; i++) {
      if (oCatalogo[i].obtemNome().equals(nome)) {
        return i;
      }
    }
    return -1; // Nome no encontrado.
  }

  /** Adiciona uma entrada ao catlogo.
      @param nome O nome da nova pessoa
      @param numero O nmero da nova pessoa
   */
  private void adiciona(String nome, String numero) {
    if (tamanho >= capacidade) {
      realoca();
    }
    oCatalogo[tamanho] = new EntradaCatalogo(nome, numero);
    tamanho++;
  }

  /** Aloca um novo vetor para o armazenamento do catlogo. */
  private void realoca() {
    capacidade *= 2;
    EntradaCatalogo[] novoCatalogo = new EntradaCatalogo[capacidade];
    System.arraycopy(oCatalogo, 0, novoCatalogo, 0,
                     oCatalogo.length);
    oCatalogo = novoCatalogo;
  }

/**** EXERCCIO ****/
}
