import java.util.*;

/** Essa classe  uma implementao de InterfaceUsuarioCT
 *   que usa o console para exibir o menu de opes de comando.
 *   @author Koffman & Wolfgang
 */
public class IUConsoleCT
    implements InterfaceUsuarioCT {

  /** Uma referncia ao objeto CatalogoTelefonico a ser processado.
      Globalmente disponvel para os mtodos de processamento de comandos.
   */
  private CatalogoTelefonico oCatalogo = null;

  /** Objeto Scanner para a leitura do console entrada. */
  private Scanner scEntrada = null;

  // Construtor
  /** Construtor padro. */
  public IUConsoleCT() {
    scEntrada = new Scanner(System.in);
  }

  // Mtodos
  /** Mtodo para exibio das opes de comando e processamento de 
      comandos do usurio.
      pr: O catlogo existe e foi carregado com dados.
      ps: O catlogo  atualizado com base nos comandos do usurio.
      @param oCatalogoTelefonico Uma referncia ao objeto CatalogoTelefonico 
             a ser processado.
   */
  public void processaComandos(CatalogoTelefonico oCatalogoTelefonico) {
    String[] comandos = {
        "Adicionar/Alterar Entrada",
        "Procurar Entrada",
        "Remover Entrada",
        "Salvar Catlogo",
        "Sair"};

    oCatalogo = oCatalogoTelefonico;
    int opcao;
    do {
      for (int i = 0; i < comandos.length; i++) {
          System.out.println("Selecione " + i + ": " 
			     + comandos[i]);
        }
        try {
	  opcao = scEntrada.nextInt();
          scEntrada.nextLine(); // Ignora linhas vazias.
        switch (opcao) {
          case 0:
            executaInclusaoOuAlteracaoDeEntrada();
            break;
          case 1:
            executaProcuraEntrada();
            break;
          case 2:
            executaRemocaoDeEntrada();
            break;
          case 3:
          case 4:
            executaGravacao();
            break;
          default:
            System.out.println("*** Escolha invlida "
			       + opcao
			       + " - tente novamente!");
        }
      }   
      catch (InputMismatchException ex) {
        System.out.println("*** Entrada de dados incorreta - "
                           + "entre um inteiro entre 0 e "
                           + (comandos.length-1));
        scEntrada.nextLine(); // Descarta entrada errada.
        opcao = -1;
      }
    } 
    while (opcao < comandos.length -1);
    System.exit(0);
  }

  /** Mtodo para a incluso ou alterao de uma entrada.
      pr: O catlogo existe e foi carregado com dados.
      ps: Um novo nome  adicionado ou o valor do nome  alterado,
           modificado  configurada com true.
   */
  private void executaInclusaoOuAlteracaoDeEntrada() {
    // Solicita o nome.
    System.out.println("Insira o nome");
    String novoNome = scEntrada.nextLine();
    if (novoNome.equals("")) {
      return;
    }
    // Solicita o nmero.
    System.out.println("Insira o nmero");
    String novoNumero = scEntrada.nextLine();
    if (novoNumero.equals("")) {
      return;
    }
    // Insere/altera nome-nmero.
    String numeroAnt =
        oCatalogo.adicionaOuAlteraEntrada(novoNome, novoNumero);
    String mensagem;
    if (numeroAnt == null) { // Nova entrada.
      mensagem = novoNome + " foi adicionado ao catlogo"
          + "\nNmero novo: " + novoNumero;
    }
    else { // Entrada alterada.
      mensagem = "O nmero de " + novoNome + " foi alterado"
          + "\nNmero antigo: " + numeroAnt
          + "\nNmero novo: " + novoNumero;
    }
    // Exibe mensagem de confirmao.
    System.out.println(mensagem);
  }

  /** Mtodo de procura de uma entrada.
      pr: O catlogo foi carregado com dados.
      ps: Nenhuma alterao  feita no catlogo.
   */
  private void executaProcuraEntrada() {
    // Solicita o nome.
    System.out.println("Insira o nome");
    String oNome = scEntrada.nextLine();
    if (oNome.equals("")) {
      return; // A caixa de dilogo foi cancelada.
    }
    // Procura o nome.
    String oNumero = oCatalogo.procuraEntrada(oNome);
    String mensagem;
    if (oNumero != null) { // O nome foi encontrado.
      mensagem = "O nmero de " + oNome + "  " + oNumero;
    }
    else { // O nome no foi encontrado.
      mensagem = oNome + " no est listado no catlogo.";
    }
    // Exibe o resultado.
    System.out.println(mensagem);
  }

  /** Mtodo para a remoo de uma entrada.
      pr: O catlogo foi carregado com dados.
      ps: O nome solicitado  removido, modificado  configurada com true.
   */
  private void executaRemocaoDeEntrada(){
    /**** EXERCCIO ****/
  }

  /** Mtodo para gravao do catlogo no arquivo de dados.
      pr: O catlogo foi carregado com dados.
      ps: O contedo atual do catlogo foi salvo no 
           arquivo de dados.
   */
  private void executaGravacao() {
    oCatalogo.salva();
  }
}
