import javax.swing.*;

/** Essa classe  uma implementao de InterfaceUsuarioCT que usa 
    JOptionPane para exibir o menu de opes de comando.
    @author Koffman & Wolfgang
 */

public class IUGCT
    implements InterfaceUsuarioCT {

  /** Uma referncia ao objeto CatalogoTelefonico a ser processado.
        Globalmente disponvel para os mtodos de processamento de comandos.
   */
  private CatalogoTelefonico oCatalogo = null;

  // Mtodos
  /** Mtodo para exibio das opes de comando e processamento de 
      comandos do usurio.
      pr: O catlogo existe e foi carregado com dados.
      ps: O catlogo  atualizado com base nos comandos do usurio.
      @param oCatalogoTelefonico Uma referncia ao objeto
             CatalogoTelefonico a ser processado.
   */
  public void processaComandos(CatalogoTelefonico oCatalogoTelefonico) {

    String[] comandos = {
        "Adicionar/Alterar Entrada",
        "Procurar Entrada",
        "Remover Entrada",
        "Salvar Catlogo",
        "Sair"};

    oCatalogo = oCatalogoTelefonico;
    int opcao;

    do {
      opcao = JOptionPane.showOptionDialog(
          null, // No tem pai
          "Selecione um comando", // Mensagem do prompt
          "Catlogo Telefnico", // Ttulo da janela
          JOptionPane.YES_NO_CANCEL_OPTION, // Tipo de opes
          JOptionPane.QUESTION_MESSAGE, // Tipo de mensagem
          null, // cone
          comandos, // Lista de comandos
          comandos[comandos.length - 1]); // Opo padro
      switch (opcao) {
        case 0:
          executaInclusaoOuAlteracaoEntrada();
          break;
        case 1:
          executaProcuraEntrada();
          break;
        case 2:
          executaRemocaoDeEntrada();
          break;
        case 3:
        case 4:
          executaGravacao();
          break;
        default: // No faz nada.
      }
    }
    while (opcao < comandos.length - 1);
    System.exit(0);
  }

  /** Mtodo para a incluso ou alterao de uma entrada.
      pr: O catlogo existe e foi carregado com dados.
      ps: Um novo nome  adicionado ou o valor do nome  alterado, 
           modificado  configurada com true.
   */
  private void executaInclusaoOuAlteracaoEntrada() {
    // Solicita o nome
    String novoNome = JOptionPane.showInputDialog("Insira o nome");
    if (novoNome == null) {
      return; // A caixa de dilogo foi cancelada. 
    }
    // Solicita o nmero
    String novoNumero = JOptionPane.showInputDialog("Insira o nmero");
    if (novoNumero == null) {
      return; // A caixa de dilogo foi cancelada. 
    }
    // Insere/altera nome-nmero
    String numeroAnt = oCatalogo.adicionaOuAlteraEntrada(novoNome,
        novoNumero);
    String mensagem = null;
    if (numeroAnt == null) { // Nova entrada
      mensagem = novoNome + " foi adicionado ao catlogo"
          + "\nNovo nmero: " + novoNumero;
    }
    else { // Entrada alterada.
      mensagem = "O nmero de " + novoNome + " foi alterado "
          + "\nNmero anterior: " + numeroAnt
          + "\nNovo nmero: " + novoNumero;
    }
    // Exibe mensagem de confirmao.
    JOptionPane.showMessageDialog(null, mensagem);
  }

  /** Mtodo de busca de uma entrada.
      pr: O catlogo foi carregado com dados.
      ps: Nenhuma alterao  feita no catlogo.
   */
  private void executaProcuraEntrada() {
    // Solicita o nome.
    String oNome = JOptionPane.showInputDialog("Insira o nome");
    if (oNome == null) {
      return; // A caixa de dilogo foi cancelada. 
    }
    // Procura o nome.
    String oNumero = oCatalogo.procuraEntrada(oNome);
    String mensagem = null;
    if (oNumero != null) { // O nome foi encontrado.
      mensagem = "O nmero de " + oNome + "  " + oNumero;
    }
    else { // O nome no foi encontrado.
      mensagem = oNome + " no est listado no catlogo";
    }
    // Exibe o resultado.
    JOptionPane.showMessageDialog(null, mensagem);
  }

  /** Mtodo para a remoo de uma entrada.
      pr: O catlogo foi carregado com dados.
      ps: O nome solicitado  removido, modificado  configurada com true.
   */
  private void executaRemocaoDeEntrada() {
   /**** EXERCCIO ****/
  }

  /** Mtodo para gravao do catlogo no arquivo de dados.
      pr: O catlogo foi carregado com dados.
      ps: O contedo atual do catlogo foi salvo no arquivo 
           de dados.
   */
  private void executaGravacao() {
    oCatalogo.salva();
  }

}
